package fitconnect.api;

import com.nimbusds.jose.jwk.RSAKey;
import fitconnect.api.auth.OAuthToken;

/**
 * A technical system that creates a submission via the Submission API.
 */
public interface Sender {

    /**
     * Authenticates the sender against the FIT-Co API and retrieves an authentication token
     *
     * @param clientId - a unique identifier within the FIT-Co platform environment
     * @param clientSecret - a secret that is only known by the application and the OAuth server
     * @param scope - OAuth scope(s) that determines if a submission is accepted by the client
     * @return {@link OAuthToken} that holds the access-token
     */
    OAuthToken retrieveAuthenticationToken(final String clientId, final String clientSecret, String... scope);

    /**
     * Encrypts the submission data with JWE.
     *
     * @param unencryptedData - unencrypted JSON or XML data as string
     * @return encrypted JSON or XML data as string
     */
     String encryptData(RSAKey publicKey, String unencryptedData);

    /**
     * Encrypts a submission attachment with JWE.
     *
     * @param unencryptedAttachment - unencrypted bytes of the attachment
     * @return encrypted JWE string serialization of the attachment
     */
    String encryptAttachment(RSAKey publicKey, byte[] unencryptedAttachment);
}
